@@ -397,7 +397,7 @@ def test_advanced_exclude_nested_lists(exclude, expected):
     assert s.to_python(data, exclude=exclude) == expected
 
 
-def test_function_plain_field_serializer():
+def test_function_plain_field_serializer_to_python():
     @dataclasses.dataclass
     class Model:
         x: int
@@ -420,7 +420,7 @@ def test_function_plain_field_serializer():
     assert s.to_python(Model(x=1000)) == {'x': '1_000'}
 
 
-def test_function_wrap_field_serializer():
+def test_function_wrap_field_serializer_to_python():
     @dataclasses.dataclass
     class Model:
         x: int
@@ -446,3 +446,54 @@ def test_function_wrap_field_serializer():
         )
     )
     assert s.to_python(Model(x=1000)) == {'x': '1_000'}
+
+
+def test_function_plain_field_serializer_to_json():
+    @dataclasses.dataclass
+    class Model:
+        x: int
+
+        def ser_x(self, v: Any, _) -> str:
+            return f'{v:_}'
+
+    s = SchemaSerializer(
+        core_schema.model_schema(
+            Model,
+            core_schema.typed_dict_schema(
+                {
+                    'x': core_schema.typed_dict_field(
+                        core_schema.int_schema(serialization=core_schema.field_function_plain_ser_schema(Model.ser_x))
+                    )
+                }
+            ),
+        )
+    )
+    assert json.loads(s.to_json(Model(x=1000))) == {'x': '1_000'}
+
+
+def test_function_wrap_field_serializer_to_json():
+    @dataclasses.dataclass
+    class Model:
+        x: int
+
+        def ser_x(self, v: Any, serializer: core_schema.SerializeWrapHandler, _) -> str:
+            x = serializer(v)
+            return f'{x:_}'
+
+    s = SchemaSerializer(
+        core_schema.model_schema(
+            Model,
+            core_schema.typed_dict_schema(
+                {
+                    'x': core_schema.typed_dict_field(
+                        core_schema.int_schema(
+                            serialization=core_schema.field_function_wrap_ser_schema(
+                                Model.ser_x, schema=core_schema.any_schema()
+                            )
+                        )
+                    )
+                }
+            ),
+        )
+    )
+    assert json.loads(s.to_json(Model(x=1000))) == {'x': '1_000'}
