@@ -207,10 +207,7 @@ def test_list_function():
         return input_value * 2
 
     v = SchemaValidator(
-        {
-            'type': 'list',
-            'items_schema': {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f}},
-        }
+        {'type': 'list', 'items_schema': {'type': 'function-plain', 'function': {'type': 'general', 'function': f}}}
     )
 
     assert v.validate_python([1, 2, 3]) == [2, 4, 6]
@@ -221,10 +218,7 @@ def test_list_function_val_error():
         raise ValueError(f'error {input_value}')
 
     v = SchemaValidator(
-        {
-            'type': 'list',
-            'items_schema': {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f}},
-        }
+        {'type': 'list', 'items_schema': {'type': 'function-plain', 'function': {'type': 'general', 'function': f}}}
     )
 
     with pytest.raises(ValidationError) as exc_info:
@@ -240,10 +234,7 @@ def test_list_function_internal_error():
         raise RuntimeError(f'error {input_value}')
 
     v = SchemaValidator(
-        {
-            'type': 'list',
-            'items_schema': {'type': 'function', 'mode': 'plain', 'function': {'type': 'general', 'function': f}},
-        }
+        {'type': 'list', 'items_schema': {'type': 'function-plain', 'function': {'type': 'general', 'function': f}}}
     )
 
     with pytest.raises(RuntimeError, match='^error 1$') as exc_info:
@@ -279,13 +270,13 @@ def test_generator_error():
     [
         pytest.param(
             {1: 10, 2: 20, '3': '30'}.items(),
-            {'type': 'tuple', 'items_schema': {'type': 'any'}},
+            {'type': 'tuple-variable', 'items_schema': {'type': 'any'}},
             [(1, 10), (2, 20), ('3', '30')],
             id='Tuple[Any, Any]',
         ),
         pytest.param(
             {1: 10, 2: 20, '3': '30'}.items(),
-            {'type': 'tuple', 'items_schema': {'type': 'int'}},
+            {'type': 'tuple-variable', 'items_schema': {'type': 'int'}},
             [(1, 10), (2, 20), (3, 30)],
             id='Tuple[int, int]',
         ),
